# -*- coding: utf-8 -*-
from django.core.urlresolvers import reverse
from django.contrib.syndication.feeds import Feed, FeedDoesNotExist
from django.utils.translation import ugettext as _

from teams.models import Team
from .models import TeamEvent, GlobalEvent

import datetime


class TeamEventFeed(Feed):
    def get_object(self, bits):
        if len(bits) >= 1:
            if bits[0] == 'all':
                return 'all'
            else:
                try:
                    return Team.objects.get(lp_name=bits[0])
                except:
                    raise FeedDoesNotExist
        return None

    def items(self, obj):
        if isinstance(obj, Team):
            return TeamEvent.objects.filter(teams=obj, date_end__gt=datetime.datetime.now()).order_by('-date_begin')[:15]
        else:
            return TeamEvent.objects.filter(date_end__gt=datetime.datetime.now()).order_by('-date_begin')[:15]

    def title(self, obj):
        if isinstance(obj, Team):
            return _('Upcoming Events for %(teamname)s' % {'teamname': obj.name})
        else:
            return _('Upcoming Events')

    def link(self, obj):
        if isinstance(obj, Team):
            return reverse('team-event-list', kwargs={'team_slug': obj.lp_name})
        else:
            return reverse('event-list')


class GlobalEventFeed(TeamEventFeed):
    def items(self, obj):
        if isinstance(obj, Team):
            return GlobalEvent.objects.filter(teamevent__teams=obj, date_end__gt=datetime.datetime.now()).order_by('-date_begin')[:15]
        else:
            return GlobalEvent.objects.filter(date_end__gt=datetime.datetime.now()).order_by('-date_begin')[:15]

    def title(self, obj):
        if isinstance(obj, Team):
            return _('Upcoming Global Events where %(teamname)s is participating' % {'teamname': obj.name})
        else:
            return _('Upcoming Global Events')

    def link(self, obj):
        return reverse('event-list')
