# -*- coding: utf-8 -*-
from django.core.urlresolvers import reverse
from django.contrib.syndication.feeds import (Feed, FeedDoesNotExist)
from django.utils.translation import ugettext as _
from meetings.models import TeamMeeting
from teams.models import Team

import datetime


class TeamMeetingFeed(Feed):
    def get_object(self, bits):
        if len(bits) >= 1:
            if bits[0] == 'all':
                return 'all'
            else:
                try:
                    return Team.objects.get(lp_name=bits[0])
                except:
                    raise FeedDoesNotExist
        return None

    def items(self, obj):
        if isinstance(obj, Team):
            return TeamMeeting.objects.filter(teams=obj, date_end__gt=datetime.datetime.now()).order_by('-date_begin')[:15]
        else:
            return TeamMeeting.objects.filter(date_end__gt=datetime.datetime.now()).order_by('-date_begin')[:15]

    def title(self, obj):
        if isinstance(obj, Team):
            return _('Upcoming Meetings for %(teamname)s' % {'teamname': obj.name})
        else:
            return _('Upcoming Meetings')

    def link(self, obj):
        if isinstance(obj, Team):
            return reverse('team-meeting-list', kwargs={'team_slug': obj.lp_name})
        else:
            return reverse('meeting-list')
