# -*- coding: utf-8 -*-
from django import forms
from django.conf import settings
#pylint: disable-msg=E1102
from django.utils.translation import ugettext_lazy as _

from venues.models import Venue
from common.forms import RenderableMixin


def validate_name(name):
    if not name or not name.strip():
        raise forms.ValidationError(_(u'Please use a descriptive name for the venue.'))
    return name


class VenueForm(forms.ModelForm, RenderableMixin):
    """
    a form to create/update a new Venue
    """
    class Meta:
        model = Venue

    class Media:
        css = {'all': (
                settings.MEDIA_URL + 'css/colortip-1.0-jquery.css',
                )}
        js = (
                'http://maps.google.com/maps/api/js?sensor=false&language=%(language)s&region=%(region)s' % {'language': _('en'), 'region': _('US')},
                'http://google-maps-utility-library-v3.googlecode.com/svn/tags/markerclusterer/1.0/src/markerclusterer_packed.js',
                settings.MEDIA_URL + 'js/jquery-ubuntu-maps.js',
                settings.MEDIA_URL + 'js/colortip-1.0-jquery.js',
            )

    def clean(self):
        self.cleaned_data['name'] = validate_name(self.cleaned_data.get('name'))
        return super(VenueForm, self).clean()
